# sstar

[![license](https://img.shields.io/badge/license-Apache%202.0-red.svg)](LICENSE)
[![language](http://img.shields.io/badge/language-Python-blue.svg)](https://www.python.org/)
[![build Status](https://github.com/xin-huang/sstar/actions/workflows/build.yml/badge.svg?branch=main)](https://github.com/xin-huang/sstar/actions)
[![dry-run Status](https://github.com/xin-huang/sstar/actions/workflows/dry-run.yml/badge.svg?branch=main)](https://github.com/xin-huang/sstar/actions)
[![codecov](https://codecov.io/gh/xin-huang/sstar/branch/main/graph/badge.svg?token=71r46xjWnU)](https://codecov.io/gh/xin-huang/sstar)
[![Documentation Status](https://readthedocs.org/projects/sstar/badge/?version=latest)](https://sstar.readthedocs.io/en/latest/?badge=latest)

The manual can be found [here](https://sstar.readthedocs.io/en/latest/).
